"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const path_1 = __importDefault(require("path"));
const config_1 = __importDefault(require("../config"));
const console_1 = require("../utils/console");
const files_1 = require("../utils/files");
const github_1 = require("../utils/github");
const packages_1 = require("../utils/packages");
exports.default = (namespace, logs = true) => __awaiter(this, void 0, void 0, function* () {
    if (namespace.includes('/')) {
        // Probably the package is from a GitHub repo.
        console_1.info(chalk_1.default `Installing {underline.bold ${namespace}}...`, logs);
        const { name, branch } = github_1.parseRepository(namespace);
        try {
            const oldDir = path_1.default.resolve(config_1.default.path, `${name}-${branch}`);
            const dir = path_1.default.resolve(config_1.default.path, `${name}`);
            console_1.info('Cloning repository from GitHub...', logs);
            yield github_1.cloneRepository(namespace, config_1.default.path);
            yield files_1.move(oldDir, dir);
            yield packages_1.updatePackage(dir, { namespace });
            console_1.info("Installing package's dependencies...", logs);
            yield packages_1.npmInstall(dir, logs);
            console_1.success(chalk_1.default `Successfully installed {underline.bold ${namespace}}!`, logs);
        }
        catch (e) {
            throw e;
        }
    }
    else {
        console_1.error(chalk_1.default `Package name '{underline.bold ${namespace}}' is not a GitHub repository`, logs);
    }
});
//# sourceMappingURL=install.js.map