"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const path_1 = __importDefault(require("path"));
const install_1 = __importDefault(require("./install"));
const config_1 = __importDefault(require("../config"));
const console_1 = require("../utils/console");
const files_1 = require("../utils/files");
const github_1 = require("../utils/github");
const packages_1 = require("../utils/packages");
const request_1 = __importDefault(require("../utils/request"));
exports.default = (namespace, logs = true) => __awaiter(this, void 0, void 0, function* () {
    const { branch, name, owner } = github_1.parseRepository(namespace);
    if (name) {
        const pluginPath = path_1.default.resolve(config_1.default.path, name);
        const { version } = yield packages_1.readPackage(pluginPath);
        try {
            console_1.info(chalk_1.default `Checking for updates for package {underline.bold ${namespace}}`, logs);
            const pkgInfo = yield request_1.default(`https://api.github.com/repos/${owner}/${name}/contents/package.json?branch=${branch}`);
            const newPkg = yield request_1.default(pkgInfo.download_url);
            if (version !== newPkg.version) {
                console_1.info(`Current package version: ${version}`, logs);
                console_1.info(`New package version: ${newPkg.version}`, logs);
                yield files_1.remove(pluginPath);
                yield install_1.default(namespace, logs);
                console_1.success(chalk_1.default `Successfully updated package {underline.bold ${namespace}}!`, logs);
            }
            else {
                console_1.success(chalk_1.default `Package {underline.bold ${namespace}} is already up to date!`, logs);
            }
        }
        catch (e) {
            throw e;
        }
    }
    console_1.error('Invalid package name', logs);
});
//# sourceMappingURL=update.js.map