"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const decompress_1 = __importDefault(require("decompress"));
const fs_1 = require("fs");
const path_1 = __importDefault(require("path"));
const files_1 = require("./files");
const request_1 = __importDefault(require("./request"));
exports.parseRepository = (repo) => {
    const owner = repo.split('/')[0];
    let branch = 'master';
    let name = repo.split('/')[1];
    if (name && name.includes('#')) {
        branch = name.split('#')[1];
        name = name.split('#')[0];
    }
    return { owner, name, branch };
};
exports.repoTypeCheck = (repo) => {
    if (typeof repo === 'string') {
        return exports.parseRepository(repo);
    }
    return repo;
};
exports.getArchiveLink = (repo) => {
    const { owner, name, branch } = exports.repoTypeCheck(repo);
    return `https://github.com/${owner}/${name}/archive/${branch}.zip`;
};
exports.cloneRepository = (repo, dest) => new Promise((resolve, reject) => {
    const { name, owner, branch } = exports.repoTypeCheck(repo);
    const zipPath = path_1.default.resolve(dest, `${owner}:${name}#${branch}.zip`);
    const file = fs_1.createWriteStream(zipPath);
    request_1.default(exports.getArchiveLink(repo), file)
        .then(() => {
        decompress_1.default(zipPath, dest)
            .then(() => {
            files_1.remove(zipPath).then(() => {
                resolve();
            });
        })
            .catch(e => {
            reject(e);
        });
    })
        .catch(e => {
        reject(e);
    });
});
//# sourceMappingURL=github.js.map