"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const child_process_1 = require("child_process");
const files_1 = require("../utils/files");
function readPackage(dir) {
    return __awaiter(this, void 0, void 0, function* () {
        const packagePath = path_1.default.resolve(dir, 'package.json');
        const namespace = path_1.default.basename(dir);
        if (yield files_1.exists(packagePath)) {
            return JSON.parse(yield files_1.readFile(packagePath, 'utf8'));
        }
        throw new Error(`Couldn't find package.json for plugin ${namespace}.`);
    });
}
exports.readPackage = readPackage;
function updatePackage(dir, json) {
    return __awaiter(this, void 0, void 0, function* () {
        const pkg = yield readPackage(dir);
        return files_1.writeFile(path_1.default.resolve(dir, 'package.json'), JSON.stringify(Object.assign({}, pkg, json)));
    });
}
exports.updatePackage = updatePackage;
function getDependencies(dir) {
    return __awaiter(this, void 0, void 0, function* () {
        const pkg = yield readPackage(dir);
        const deps = [];
        for (const key in pkg.dependencies) {
            deps.push(`${key}@${pkg.dependencies[key]}`);
        }
        return deps;
    });
}
exports.getDependencies = getDependencies;
function npmInstall(dir, logs = true) {
    return __awaiter(this, void 0, void 0, function* () {
        return new Promise((resolve, reject) => __awaiter(this, void 0, void 0, function* () {
            const build = child_process_1.spawn('npm', ['install'], {
                cwd: dir,
                shell: true,
            });
            build.on('close', code => {
                if (code === 0) {
                    resolve(code);
                }
                else {
                    reject(code);
                }
            });
        }));
    });
}
exports.npmInstall = npmInstall;
//# sourceMappingURL=packages.js.map